@@ -1,10 +1,13 @@
 #ifndef TREEEVENTMAP_H
 #define TREEEVENTMAP_H
 //#include "treeeventnode.h"
-#include <map>
-#include <R.h>
-#include <Rinternals.h>
+//#include <map>
 #include "eventseq.h"
+extern "C"{
+	#include <R.h>
+	#include <Rinternals.h>
+}
+
 //using namespace std;
 
 //Forward declaration
